aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/frotz/frotz.h
diff options
context:
space:
mode:
authorPaul Gilbert2019-06-16 13:29:15 -0700
committerPaul Gilbert2019-06-16 14:59:26 -0700
commit553bb74f8c380ee31fb771c6619dad8e83fed8ce (patch)
treebf99be6554e96d66d2700837d7c08dc0d48ad127 /engines/glk/frotz/frotz.h
parent3876fb67108284063b4d133cf087a04dae6993e4 (diff)
downloadscummvm-rg350-553bb74f8c380ee31fb771c6619dad8e83fed8ce.tar.gz
scummvm-rg350-553bb74f8c380ee31fb771c6619dad8e83fed8ce.tar.bz2
scummvm-rg350-553bb74f8c380ee31fb771c6619dad8e83fed8ce.zip
GLK: Further changeover of sub-engines to use new savegame code
Diffstat (limited to 'engines/glk/frotz/frotz.h')
-rw-r--r--engines/glk/frotz/frotz.h19
1 files changed, 15 insertions, 4 deletions
diff --git a/engines/glk/frotz/frotz.h b/engines/glk/frotz/frotz.h
index 8312e16b49..a8083a3093 100644
--- a/engines/glk/frotz/frotz.h
+++ b/engines/glk/frotz/frotz.h
@@ -72,14 +72,25 @@ public:
virtual void runGame() override;
/**
* Load a savegame from the passed stream
*/
- virtual Common::Error loadGameData(strid_t file) override;
+ virtual Common::Error loadGameState(int slot) override;
/**
* Save the game to the passed stream
*/
- virtual Common::Error saveGameData(strid_t file, const Common::String &desc) override;
+ virtual Common::Error saveGameState(int slot, const Common::String &desc) override;
+
+ /**
+ * Loading method not used for Frotz sub-engine
+ */
+ virtual Common::Error readSaveData(Common::SeekableReadStream *rs) override { return Common::kReadingFailed; }
+
+ /**
+ * Saving method not used for Frotz sub-engine
+ */
+ virtual Common::Error writeGameData(Common::WriteStream *ws) override { return Common::kWritingFailed; }
+
};
extern Frotz *g_vm;
@@ -72,14 +72,25 @@ public:
virtual void runGame() override;
/**
- * Load a savegame from the passed stream
+ * Load a savegame from a given slot
*/
@@ -72,14 +72,25 @@ public:
/**
- * Save the game to the passed stream
+ * Save the game to a given slot
*/